@@ -14,7 +14,7 @@
 
 SRWL=/sbin/shorewall6
 SRWL_OPTS="-tvv"
-WAIT_FOR_IFUP=/usr/share/shorewall6/wait4ifup
+WAIT_FOR_IFUP=/usr/share/shorewall/wait4ifup
 test -n ${INITLOG:=/var/log/shorewall6-init.log}
 
 test -x $SRWL || exit 0
@@ -86,7 +86,7 @@ wait_for_pppd () {
 shorewall6_start () {
   echo -n "Starting \"Shorewall6 firewall\": "
   wait_for_pppd
-  $SRWL $SRWL_OPTS start >> $INITLOG 2>&1 && echo "done." || echo_notdone
+  $SRWL $SRWL_OPTS start $STARTOPTIONS >> $INITLOG 2>&1 && echo "done." || echo_notdone
   return 0
 }
 
@@ -104,7 +104,7 @@ shorewall6_stop () {
 # restart the firewall
 shorewall6_restart () {
   echo -n "Restarting \"Shorewall6 firewall\": "
-  $SRWL $SRWL_OPTS restart >> $INITLOG 2>&1 && echo "done." || echo_notdone
+  $SRWL $SRWL_OPTS restart $RESTARTOPTIONS >> $INITLOG 2>&1 && echo "done." || echo_notdone
   return 0
 }
 
